from ctypes import c_uint

__all__ = [
    'CorsairDeviceType', 'CorsairPhysicalLayout', 'CorsairLogicalLayout',
    'CorsairDeviceCaps', 'CorsairAccessMode', 'CorsairError',
    'CorsairChannelDeviceType', 'CorsairDevicePropertyType',
    'CorsairDevicePropertyId', 'CorsairEventId', 'CorsairKeyId', 'CorsairLedId'
]


class EnumerationType(type(c_uint)):
    def __new__(metacls, name, bases, dictcls):
        if "_members_" not in dictcls:
            _members_ = {}
            for key, value in dictcls.items():
                if not key.startswith("_"):
                    _members_[key] = value

            dictcls["_members_"] = _members_
        else:
            _members_ = dictcls["_members_"]

        dictcls["_reverse_map_"] = {v: k for k, v in _members_.items()}
        return type(c_uint).__new__(metacls, name, bases, dictcls)

    def __repr__(self):
        return "<Enumeration %s>" % self.__name__


class Enumeration(c_uint, metaclass=EnumerationType):
    _members_ = {}

    def __repr__(self):
        return "<%s: %d>" % (self.__str__(), self.value)

    def __str__(self):
        return "%s.%s" % (self.__class__.__name__,
                          self._reverse_map_.get(self.value, '(unknown)'))

    def __hash__(self):
        return self.value

    def __eq__(self, other):
        if isinstance(other, int):
            return self.value == other

        return type(self) == type(other) and self.value == other.value

    def __lt__(self, other):
        if isinstance(other, int):
            return self.value < other

        return type(self) == type(other) and self.value < other.value


class CorsairDeviceType(Enumeration):
    Unknown = 0
    Mouse = 1
    Keyboard = 2
    Headset = 3
    MouseMat = 4
    HeadsetStand = 5
    CommanderPro = 6
    LightingNodePro = 7
    MemoryModule = 8
    Cooler = 9
    Motherboard = 10
    GraphicsCard = 11


class CorsairPhysicalLayout(Enumeration):
    Invalid = 0
    US = 1
    UK = 2
    BR = 3
    JP = 4
    KR = 5
    Zones1 = 6
    Zones2 = 7
    Zones3 = 8
    Zones4 = 9
    Zones5 = 10
    Zones6 = 11
    Zones7 = 12
    Zones8 = 13
    Zones9 = 14
    Zones10 = 15
    Zones11 = 16
    Zones12 = 17
    Zones13 = 18
    Zones14 = 19
    Zones15 = 20
    Zones16 = 21
    Zones17 = 22
    Zones18 = 23
    Zones19 = 24
    Zones20 = 25


class CorsairLogicalLayout(Enumeration):
    Invalid = 0
    US_Int = 1
    NA = 2
    EU = 3
    UK = 4
    BE = 5
    BR = 6
    CH = 7
    CN = 8
    DE = 9
    ES = 10
    FR = 11
    IT = 12
    ND = 13
    RU = 14
    JP = 15
    KR = 16
    TW = 17
    MEX = 18


class CorsairDeviceCaps(Enumeration):
    NoCaps = 0x0000
    Lighting = 0x0001
    PropertyLookup = 0x0002


class CorsairAccessMode(Enumeration):
    ExclusiveLightingControl = 0


class CorsairError(Enumeration):
    Success = 0
    ServerNotFound = 1
    NoControl = 2
    ProtocolHandshakeMissing = 3
    IncompatibleProtocol = 4
    InvalidArguments = 5


class CorsairChannelDeviceType(Enumeration):
    Invalid = 0
    HD_Fan = 1
    SP_Fan = 2
    LL_Fan = 3
    ML_Fan = 4
    Strip = 5
    DAP = 6
    Pump = 7
    QL_Fan = 8,
    WaterBlock = 9,
    SPPRO_Fan = 10


class CorsairDevicePropertyType(Enumeration):
    Boolean = 0x1000
    Int32 = 0x2000


class CorsairDevicePropertyId(Enumeration):
    Headset_MicEnabled = 0x1000
    Headset_SurroundSoundEnabled = 0x1001
    Headset_SidetoneEnabled = 0x1002
    Headset_EqualizerPreset = 0x2000


class CorsairEventId(Enumeration):
    Invalid = 0
    DeviceConnectionStatusChangedEvent = 1
    KeyEvent = 2


class CorsairKeyId(Enumeration):
    Invalid = 0
    Kb_G1 = 1
    Kb_G2 = 2
    Kb_G3 = 3
    Kb_G4 = 4
    Kb_G5 = 5
    Kb_G6 = 6
    Kb_G7 = 7
    Kb_G8 = 8
    Kb_G9 = 9
    Kb_G10 = 10
    Kb_G11 = 11
    Kb_G12 = 12
    Kb_G13 = 13
    Kb_G14 = 14
    Kb_G15 = 15
    Kb_G16 = 16
    Kb_G17 = 17
    Kb_G18 = 18
    Mouse_M1 = 19
    Mouse_M2 = 20
    Mouse_M3 = 21
    Mouse_M4 = 22
    Mouse_M5 = 23
    Mouse_M6 = 24
    Mouse_M7 = 25
    Mouse_M8 = 26
    Mouse_M9 = 27
    Mouse_M10 = 28
    Mouse_M11 = 29
    Mouse_M12 = 30
    Last = Mouse_M12


class CorsairLedId(Enumeration):
    Invalid = 0
    K_Escape = 1
    K_F1 = 2
    K_F2 = 3
    K_F3 = 4
    K_F4 = 5
    K_F5 = 6
    K_F6 = 7
    K_F7 = 8
    K_F8 = 9
    K_F9 = 10
    K_F10 = 11
    K_F11 = 12
    K_GraveAccentAndTilde = 13
    K_1 = 14
    K_2 = 15
    K_3 = 16
    K_4 = 17
    K_5 = 18
    K_6 = 19
    K_7 = 20
    K_8 = 21
    K_9 = 22
    K_0 = 23
    K_MinusAndUnderscore = 24
    K_Tab = 25
    K_Q = 26
    K_W = 27
    K_E = 28
    K_R = 29
    K_T = 30
    K_Y = 31
    K_U = 32
    K_I = 33
    K_O = 34
    K_P = 35
    K_BracketLeft = 36
    K_CapsLock = 37
    K_A = 38
    K_S = 39
    K_D = 40
    K_F = 41
    K_G = 42
    K_H = 43
    K_J = 44
    K_K = 45
    K_L = 46
    K_SemicolonAndColon = 47
    K_ApostropheAndDoubleQuote = 48
    K_LeftShift = 49
    K_NonUsBackslash = 50
    K_Z = 51
    K_X = 52
    K_C = 53
    K_V = 54
    K_B = 55
    K_N = 56
    K_M = 57
    K_CommaAndLessThan = 58
    K_PeriodAndBiggerThan = 59
    K_SlashAndQuestionMark = 60
    K_LeftCtrl = 61
    K_LeftGui = 62
    K_LeftAlt = 63
    K_Lang2 = 64
    K_Space = 65
    K_Lang1 = 66
    K_International2 = 67
    K_RightAlt = 68
    K_RightGui = 69
    K_Application = 70
    K_LedProgramming = 71
    K_Brightness = 72
    K_F12 = 73
    K_PrintScreen = 74
    K_ScrollLock = 75
    K_PauseBreak = 76
    K_Insert = 77
    K_Home = 78
    K_PageUp = 79
    K_BracketRight = 80
    K_Backslash = 81
    K_NonUsTilde = 82
    K_Enter = 83
    K_International1 = 84
    K_EqualsAndPlus = 85
    K_International3 = 86
    K_Backspace = 87
    K_Delete = 88
    K_End = 89
    K_PageDown = 90
    K_RightShift = 91
    K_RightCtrl = 92
    K_UpArrow = 93
    K_LeftArrow = 94
    K_DownArrow = 95
    K_RightArrow = 96
    K_WinLock = 97
    K_Mute = 98
    K_Stop = 99
    K_ScanPreviousTrack = 100
    K_PlayPause = 101
    K_ScanNextTrack = 102
    K_NumLock = 103
    K_KeypadSlash = 104
    K_KeypadAsterisk = 105
    K_KeypadMinus = 106
    K_KeypadPlus = 107
    K_KeypadEnter = 108
    K_Keypad7 = 109
    K_Keypad8 = 110
    K_Keypad9 = 111
    K_KeypadComma = 112
    K_Keypad4 = 113
    K_Keypad5 = 114
    K_Keypad6 = 115
    K_Keypad1 = 116
    K_Keypad2 = 117
    K_Keypad3 = 118
    K_Keypad0 = 119
    K_KeypadPeriodAndDelete = 120
    K_G1 = 121
    K_G2 = 122
    K_G3 = 123
    K_G4 = 124
    K_G5 = 125
    K_G6 = 126
    K_G7 = 127
    K_G8 = 128
    K_G9 = 129
    K_G10 = 130
    K_VolumeUp = 131
    K_VolumeDown = 132
    K_MR = 133
    K_M1 = 134
    K_M2 = 135
    K_M3 = 136
    K_G11 = 137
    K_G12 = 138
    K_G13 = 139
    K_G14 = 140
    K_G15 = 141
    K_G16 = 142
    K_G17 = 143
    K_G18 = 144
    K_International5 = 145
    K_International4 = 146
    K_Fn = 147
    M_1 = 148
    M_2 = 149
    M_3 = 150
    M_4 = 151
    H_LeftLogo = 152
    H_RightLogo = 153
    K_Logo = 154
    MM_Zone1 = 155
    MM_Zone2 = 156
    MM_Zone3 = 157
    MM_Zone4 = 158
    MM_Zone5 = 159
    MM_Zone6 = 160
    MM_Zone7 = 161
    MM_Zone8 = 162
    MM_Zone9 = 163
    MM_Zone10 = 164
    MM_Zone11 = 165
    MM_Zone12 = 166
    MM_Zone13 = 167
    MM_Zone14 = 168
    MM_Zone15 = 169
    KLP_Zone1 = 170
    KLP_Zone2 = 171
    KLP_Zone3 = 172
    KLP_Zone4 = 173
    KLP_Zone5 = 174
    KLP_Zone6 = 175
    KLP_Zone7 = 176
    KLP_Zone8 = 177
    KLP_Zone9 = 178
    KLP_Zone10 = 179
    KLP_Zone11 = 180
    KLP_Zone12 = 181
    KLP_Zone13 = 182
    KLP_Zone14 = 183
    KLP_Zone15 = 184
    KLP_Zone16 = 185
    KLP_Zone17 = 186
    KLP_Zone18 = 187
    KLP_Zone19 = 188
    M_5 = 189
    M_6 = 190
    HSS_Zone1 = 191
    HSS_Zone2 = 192
    HSS_Zone3 = 193
    HSS_Zone4 = 194
    HSS_Zone5 = 195
    HSS_Zone6 = 196
    HSS_Zone7 = 197
    HSS_Zone8 = 198
    HSS_Zone9 = 199
    D_C1_1 = 200
    D_C1_2 = 201
    D_C1_3 = 202
    D_C1_4 = 203
    D_C1_5 = 204
    D_C1_6 = 205
    D_C1_7 = 206
    D_C1_8 = 207
    D_C1_9 = 208
    D_C1_10 = 209
    D_C1_11 = 210
    D_C1_12 = 211
    D_C1_13 = 212
    D_C1_14 = 213
    D_C1_15 = 214
    D_C1_16 = 215
    D_C1_17 = 216
    D_C1_18 = 217
    D_C1_19 = 218
    D_C1_20 = 219
    D_C1_21 = 220
    D_C1_22 = 221
    D_C1_23 = 222
    D_C1_24 = 223
    D_C1_25 = 224
    D_C1_26 = 225
    D_C1_27 = 226
    D_C1_28 = 227
    D_C1_29 = 228
    D_C1_30 = 229
    D_C1_31 = 230
    D_C1_32 = 231
    D_C1_33 = 232
    D_C1_34 = 233
    D_C1_35 = 234
    D_C1_36 = 235
    D_C1_37 = 236
    D_C1_38 = 237
    D_C1_39 = 238
    D_C1_40 = 239
    D_C1_41 = 240
    D_C1_42 = 241
    D_C1_43 = 242
    D_C1_44 = 243
    D_C1_45 = 244
    D_C1_46 = 245
    D_C1_47 = 246
    D_C1_48 = 247
    D_C1_49 = 248
    D_C1_50 = 249
    D_C1_51 = 250
    D_C1_52 = 251
    D_C1_53 = 252
    D_C1_54 = 253
    D_C1_55 = 254
    D_C1_56 = 255
    D_C1_57 = 256
    D_C1_58 = 257
    D_C1_59 = 258
    D_C1_60 = 259
    D_C1_61 = 260
    D_C1_62 = 261
    D_C1_63 = 262
    D_C1_64 = 263
    D_C1_65 = 264
    D_C1_66 = 265
    D_C1_67 = 266
    D_C1_68 = 267
    D_C1_69 = 268
    D_C1_70 = 269
    D_C1_71 = 270
    D_C1_72 = 271
    D_C1_73 = 272
    D_C1_74 = 273
    D_C1_75 = 274
    D_C1_76 = 275
    D_C1_77 = 276
    D_C1_78 = 277
    D_C1_79 = 278
    D_C1_80 = 279
    D_C1_81 = 280
    D_C1_82 = 281
    D_C1_83 = 282
    D_C1_84 = 283
    D_C1_85 = 284
    D_C1_86 = 285
    D_C1_87 = 286
    D_C1_88 = 287
    D_C1_89 = 288
    D_C1_90 = 289
    D_C1_91 = 290
    D_C1_92 = 291
    D_C1_93 = 292
    D_C1_94 = 293
    D_C1_95 = 294
    D_C1_96 = 295
    D_C1_97 = 296
    D_C1_98 = 297
    D_C1_99 = 298
    D_C1_100 = 299
    D_C1_101 = 300
    D_C1_102 = 301
    D_C1_103 = 302
    D_C1_104 = 303
    D_C1_105 = 304
    D_C1_106 = 305
    D_C1_107 = 306
    D_C1_108 = 307
    D_C1_109 = 308
    D_C1_110 = 309
    D_C1_111 = 310
    D_C1_112 = 311
    D_C1_113 = 312
    D_C1_114 = 313
    D_C1_115 = 314
    D_C1_116 = 315
    D_C1_117 = 316
    D_C1_118 = 317
    D_C1_119 = 318
    D_C1_120 = 319
    D_C1_121 = 320
    D_C1_122 = 321
    D_C1_123 = 322
    D_C1_124 = 323
    D_C1_125 = 324
    D_C1_126 = 325
    D_C1_127 = 326
    D_C1_128 = 327
    D_C1_129 = 328
    D_C1_130 = 329
    D_C1_131 = 330
    D_C1_132 = 331
    D_C1_133 = 332
    D_C1_134 = 333
    D_C1_135 = 334
    D_C1_136 = 335
    D_C1_137 = 336
    D_C1_138 = 337
    D_C1_139 = 338
    D_C1_140 = 339
    D_C1_141 = 340
    D_C1_142 = 341
    D_C1_143 = 342
    D_C1_144 = 343
    D_C1_145 = 344
    D_C1_146 = 345
    D_C1_147 = 346
    D_C1_148 = 347
    D_C1_149 = 348
    D_C1_150 = 349
    D_C2_1 = 350
    D_C2_2 = 351
    D_C2_3 = 352
    D_C2_4 = 353
    D_C2_5 = 354
    D_C2_6 = 355
    D_C2_7 = 356
    D_C2_8 = 357
    D_C2_9 = 358
    D_C2_10 = 359
    D_C2_11 = 360
    D_C2_12 = 361
    D_C2_13 = 362
    D_C2_14 = 363
    D_C2_15 = 364
    D_C2_16 = 365
    D_C2_17 = 366
    D_C2_18 = 367
    D_C2_19 = 368
    D_C2_20 = 369
    D_C2_21 = 370
    D_C2_22 = 371
    D_C2_23 = 372
    D_C2_24 = 373
    D_C2_25 = 374
    D_C2_26 = 375
    D_C2_27 = 376
    D_C2_28 = 377
    D_C2_29 = 378
    D_C2_30 = 379
    D_C2_31 = 380
    D_C2_32 = 381
    D_C2_33 = 382
    D_C2_34 = 383
    D_C2_35 = 384
    D_C2_36 = 385
    D_C2_37 = 386
    D_C2_38 = 387
    D_C2_39 = 388
    D_C2_40 = 389
    D_C2_41 = 390
    D_C2_42 = 391
    D_C2_43 = 392
    D_C2_44 = 393
    D_C2_45 = 394
    D_C2_46 = 395
    D_C2_47 = 396
    D_C2_48 = 397
    D_C2_49 = 398
    D_C2_50 = 399
    D_C2_51 = 400
    D_C2_52 = 401
    D_C2_53 = 402
    D_C2_54 = 403
    D_C2_55 = 404
    D_C2_56 = 405
    D_C2_57 = 406
    D_C2_58 = 407
    D_C2_59 = 408
    D_C2_60 = 409
    D_C2_61 = 410
    D_C2_62 = 411
    D_C2_63 = 412
    D_C2_64 = 413
    D_C2_65 = 414
    D_C2_66 = 415
    D_C2_67 = 416
    D_C2_68 = 417
    D_C2_69 = 418
    D_C2_70 = 419
    D_C2_71 = 420
    D_C2_72 = 421
    D_C2_73 = 422
    D_C2_74 = 423
    D_C2_75 = 424
    D_C2_76 = 425
    D_C2_77 = 426
    D_C2_78 = 427
    D_C2_79 = 428
    D_C2_80 = 429
    D_C2_81 = 430
    D_C2_82 = 431
    D_C2_83 = 432
    D_C2_84 = 433
    D_C2_85 = 434
    D_C2_86 = 435
    D_C2_87 = 436
    D_C2_88 = 437
    D_C2_89 = 438
    D_C2_90 = 439
    D_C2_91 = 440
    D_C2_92 = 441
    D_C2_93 = 442
    D_C2_94 = 443
    D_C2_95 = 444
    D_C2_96 = 445
    D_C2_97 = 446
    D_C2_98 = 447
    D_C2_99 = 448
    D_C2_100 = 449
    D_C2_101 = 450
    D_C2_102 = 451
    D_C2_103 = 452
    D_C2_104 = 453
    D_C2_105 = 454
    D_C2_106 = 455
    D_C2_107 = 456
    D_C2_108 = 457
    D_C2_109 = 458
    D_C2_110 = 459
    D_C2_111 = 460
    D_C2_112 = 461
    D_C2_113 = 462
    D_C2_114 = 463
    D_C2_115 = 464
    D_C2_116 = 465
    D_C2_117 = 466
    D_C2_118 = 467
    D_C2_119 = 468
    D_C2_120 = 469
    D_C2_121 = 470
    D_C2_122 = 471
    D_C2_123 = 472
    D_C2_124 = 473
    D_C2_125 = 474
    D_C2_126 = 475
    D_C2_127 = 476
    D_C2_128 = 477
    D_C2_129 = 478
    D_C2_130 = 479
    D_C2_131 = 480
    D_C2_132 = 481
    D_C2_133 = 482
    D_C2_134 = 483
    D_C2_135 = 484
    D_C2_136 = 485
    D_C2_137 = 486
    D_C2_138 = 487
    D_C2_139 = 488
    D_C2_140 = 489
    D_C2_141 = 490
    D_C2_142 = 491
    D_C2_143 = 492
    D_C2_144 = 493
    D_C2_145 = 494
    D_C2_146 = 495
    D_C2_147 = 496
    D_C2_148 = 497
    D_C2_149 = 498
    D_C2_150 = 499
    Oem1 = 500
    Oem2 = 501
    Oem3 = 502
    Oem4 = 503
    Oem5 = 504
    Oem6 = 505
    Oem7 = 506
    Oem8 = 507
    Oem9 = 508
    Oem10 = 509
    Oem11 = 510
    Oem12 = 511
    Oem13 = 512
    Oem14 = 513
    Oem15 = 514
    Oem16 = 515
    Oem17 = 516
    Oem18 = 517
    Oem19 = 518
    Oem20 = 519
    Oem21 = 520
    Oem22 = 521
    Oem23 = 522
    Oem24 = 523
    Oem25 = 524
    Oem26 = 525
    Oem27 = 526
    Oem28 = 527
    Oem29 = 528
    Oem30 = 529
    Oem31 = 530
    Oem32 = 531
    Oem33 = 532
    Oem34 = 533
    Oem35 = 534
    Oem36 = 535
    Oem37 = 536
    Oem38 = 537
    Oem39 = 538
    Oem40 = 539
    Oem41 = 540
    Oem42 = 541
    Oem43 = 542
    Oem44 = 543
    Oem45 = 544
    Oem46 = 545
    Oem47 = 546
    Oem48 = 547
    Oem49 = 548
    Oem50 = 549
    Oem51 = 550
    Oem52 = 551
    Oem53 = 552
    Oem54 = 553
    Oem55 = 554
    Oem56 = 555
    Oem57 = 556
    Oem58 = 557
    Oem59 = 558
    Oem60 = 559
    Oem61 = 560
    Oem62 = 561
    Oem63 = 562
    Oem64 = 563
    Oem65 = 564
    Oem66 = 565
    Oem67 = 566
    Oem68 = 567
    Oem69 = 568
    Oem70 = 569
    Oem71 = 570
    Oem72 = 571
    Oem73 = 572
    Oem74 = 573
    Oem75 = 574
    Oem76 = 575
    Oem77 = 576
    Oem78 = 577
    Oem79 = 578
    Oem80 = 579
    Oem81 = 580
    Oem82 = 581
    Oem83 = 582
    Oem84 = 583
    Oem85 = 584
    Oem86 = 585
    Oem87 = 586
    Oem88 = 587
    Oem89 = 588
    Oem90 = 589
    Oem91 = 590
    Oem92 = 591
    Oem93 = 592
    Oem94 = 593
    Oem95 = 594
    Oem96 = 595
    Oem97 = 596
    Oem98 = 597
    Oem99 = 598
    Oem100 = 599
    DRAM_1 = 600
    DRAM_2 = 601
    DRAM_3 = 602
    DRAM_4 = 603
    DRAM_5 = 604
    DRAM_6 = 605
    DRAM_7 = 606
    DRAM_8 = 607
    DRAM_9 = 608
    DRAM_10 = 609
    DRAM_11 = 610
    DRAM_12 = 611
    D_C3_1 = 612
    D_C3_2 = 613
    D_C3_3 = 614
    D_C3_4 = 615
    D_C3_5 = 616
    D_C3_6 = 617
    D_C3_7 = 618
    D_C3_8 = 619
    D_C3_9 = 620
    D_C3_10 = 621
    D_C3_11 = 622
    D_C3_12 = 623
    D_C3_13 = 624
    D_C3_14 = 625
    D_C3_15 = 626
    D_C3_16 = 627
    D_C3_17 = 628
    D_C3_18 = 629
    D_C3_19 = 630
    D_C3_20 = 631
    D_C3_21 = 632
    D_C3_22 = 633
    D_C3_23 = 634
    D_C3_24 = 635
    D_C3_25 = 636
    D_C3_26 = 637
    D_C3_27 = 638
    D_C3_28 = 639
    D_C3_29 = 640
    D_C3_30 = 641
    D_C3_31 = 642
    D_C3_32 = 643
    D_C3_33 = 644
    D_C3_34 = 645
    D_C3_35 = 646
    D_C3_36 = 647
    D_C3_37 = 648
    D_C3_38 = 649
    D_C3_39 = 650
    D_C3_40 = 651
    D_C3_41 = 652
    D_C3_42 = 653
    D_C3_43 = 654
    D_C3_44 = 655
    D_C3_45 = 656
    D_C3_46 = 657
    D_C3_47 = 658
    D_C3_48 = 659
    D_C3_49 = 660
    D_C3_50 = 661
    D_C3_51 = 662
    D_C3_52 = 663
    D_C3_53 = 664
    D_C3_54 = 665
    D_C3_55 = 666
    D_C3_56 = 667
    D_C3_57 = 668
    D_C3_58 = 669
    D_C3_59 = 670
    D_C3_60 = 671
    D_C3_61 = 672
    D_C3_62 = 673
    D_C3_63 = 674
    D_C3_64 = 675
    D_C3_65 = 676
    D_C3_66 = 677
    D_C3_67 = 678
    D_C3_68 = 679
    D_C3_69 = 680
    D_C3_70 = 681
    D_C3_71 = 682
    D_C3_72 = 683
    D_C3_73 = 684
    D_C3_74 = 685
    D_C3_75 = 686
    D_C3_76 = 687
    D_C3_77 = 688
    D_C3_78 = 689
    D_C3_79 = 690
    D_C3_80 = 691
    D_C3_81 = 692
    D_C3_82 = 693
    D_C3_83 = 694
    D_C3_84 = 695
    D_C3_85 = 696
    D_C3_86 = 697
    D_C3_87 = 698
    D_C3_88 = 699
    D_C3_89 = 700
    D_C3_90 = 701
    D_C3_91 = 702
    D_C3_92 = 703
    D_C3_93 = 704
    D_C3_94 = 705
    D_C3_95 = 706
    D_C3_96 = 707
    D_C3_97 = 708
    D_C3_98 = 709
    D_C3_99 = 710
    D_C3_100 = 711
    D_C3_101 = 712
    D_C3_102 = 713
    D_C3_103 = 714
    D_C3_104 = 715
    D_C3_105 = 716
    D_C3_106 = 717
    D_C3_107 = 718
    D_C3_108 = 719
    D_C3_109 = 720
    D_C3_110 = 721
    D_C3_111 = 722
    D_C3_112 = 723
    D_C3_113 = 724
    D_C3_114 = 725
    D_C3_115 = 726
    D_C3_116 = 727
    D_C3_117 = 728
    D_C3_118 = 729
    D_C3_119 = 730
    D_C3_120 = 731
    D_C3_121 = 732
    D_C3_122 = 733
    D_C3_123 = 734
    D_C3_124 = 735
    D_C3_125 = 736
    D_C3_126 = 737
    D_C3_127 = 738
    D_C3_128 = 739
    D_C3_129 = 740
    D_C3_130 = 741
    D_C3_131 = 742
    D_C3_132 = 743
    D_C3_133 = 744
    D_C3_134 = 745
    D_C3_135 = 746
    D_C3_136 = 747
    D_C3_137 = 748
    D_C3_138 = 749
    D_C3_139 = 750
    D_C3_140 = 751
    D_C3_141 = 752
    D_C3_142 = 753
    D_C3_143 = 754
    D_C3_144 = 755
    D_C3_145 = 756
    D_C3_146 = 757
    D_C3_147 = 758
    D_C3_148 = 759
    D_C3_149 = 760
    D_C3_150 = 761
    LC_C1_1 = 762
    LC_C1_2 = 763
    LC_C1_3 = 764
    LC_C1_4 = 765
    LC_C1_5 = 766
    LC_C1_6 = 767
    LC_C1_7 = 768
    LC_C1_8 = 769
    LC_C1_9 = 770
    LC_C1_10 = 771
    LC_C1_11 = 772
    LC_C1_12 = 773
    LC_C1_13 = 774
    LC_C1_14 = 775
    LC_C1_15 = 776
    LC_C1_16 = 777
    LC_C1_17 = 778
    LC_C1_18 = 779
    LC_C1_19 = 780
    LC_C1_20 = 781
    LC_C1_21 = 782
    LC_C1_22 = 783
    LC_C1_23 = 784
    LC_C1_24 = 785
    LC_C1_25 = 786
    LC_C1_26 = 787
    LC_C1_27 = 788
    LC_C1_28 = 789
    LC_C1_29 = 790
    LC_C1_30 = 791
    LC_C1_31 = 792
    LC_C1_32 = 793
    LC_C1_33 = 794
    LC_C1_34 = 795
    LC_C1_35 = 796
    LC_C1_36 = 797
    LC_C1_37 = 798
    LC_C1_38 = 799
    LC_C1_39 = 800
    LC_C1_40 = 801
    LC_C1_41 = 802
    LC_C1_42 = 803
    LC_C1_43 = 804
    LC_C1_44 = 805
    LC_C1_45 = 806
    LC_C1_46 = 807
    LC_C1_47 = 808
    LC_C1_48 = 809
    LC_C1_49 = 810
    LC_C1_50 = 811
    LC_C1_51 = 812
    LC_C1_52 = 813
    LC_C1_53 = 814
    LC_C1_54 = 815
    LC_C1_55 = 816
    LC_C1_56 = 817
    LC_C1_57 = 818
    LC_C1_58 = 819
    LC_C1_59 = 820
    LC_C1_60 = 821
    LC_C1_61 = 822
    LC_C1_62 = 823
    LC_C1_63 = 824
    LC_C1_64 = 825
    LC_C1_65 = 826
    LC_C1_66 = 827
    LC_C1_67 = 828
    LC_C1_68 = 829
    LC_C1_69 = 830
    LC_C1_70 = 831
    LC_C1_71 = 832
    LC_C1_72 = 833
    LC_C1_73 = 834
    LC_C1_74 = 835
    LC_C1_75 = 836
    LC_C1_76 = 837
    LC_C1_77 = 838
    LC_C1_78 = 839
    LC_C1_79 = 840
    LC_C1_80 = 841
    LC_C1_81 = 842
    LC_C1_82 = 843
    LC_C1_83 = 844
    LC_C1_84 = 845
    LC_C1_85 = 846
    LC_C1_86 = 847
    LC_C1_87 = 848
    LC_C1_88 = 849
    LC_C1_89 = 850
    LC_C1_90 = 851
    LC_C1_91 = 852
    LC_C1_92 = 853
    LC_C1_93 = 854
    LC_C1_94 = 855
    LC_C1_95 = 856
    LC_C1_96 = 857
    LC_C1_97 = 858
    LC_C1_98 = 859
    LC_C1_99 = 860
    LC_C1_100 = 861
    LC_C1_101 = 862
    LC_C1_102 = 863
    LC_C1_103 = 864
    LC_C1_104 = 865
    LC_C1_105 = 866
    LC_C1_106 = 867
    LC_C1_107 = 868
    LC_C1_108 = 869
    LC_C1_109 = 870
    LC_C1_110 = 871
    LC_C1_111 = 872
    LC_C1_112 = 873
    LC_C1_113 = 874
    LC_C1_114 = 875
    LC_C1_115 = 876
    LC_C1_116 = 877
    LC_C1_117 = 878
    LC_C1_118 = 879
    LC_C1_119 = 880
    LC_C1_120 = 881
    LC_C1_121 = 882
    LC_C1_122 = 883
    LC_C1_123 = 884
    LC_C1_124 = 885
    LC_C1_125 = 886
    LC_C1_126 = 887
    LC_C1_127 = 888
    LC_C1_128 = 889
    LC_C1_129 = 890
    LC_C1_130 = 891
    LC_C1_131 = 892
    LC_C1_132 = 893
    LC_C1_133 = 894
    LC_C1_134 = 895
    LC_C1_135 = 896
    LC_C1_136 = 897
    LC_C1_137 = 898
    LC_C1_138 = 899
    LC_C1_139 = 900
    LC_C1_140 = 901
    LC_C1_141 = 902
    LC_C1_142 = 903
    LC_C1_143 = 904
    LC_C1_144 = 905
    LC_C1_145 = 906
    LC_C1_146 = 907
    LC_C1_147 = 908
    LC_C1_148 = 909
    LC_C1_149 = 910
    LC_C1_150 = 911
    D_C1_151 = 912
    D_C1_152 = 913
    D_C1_153 = 914
    D_C1_154 = 915
    D_C1_155 = 916
    D_C1_156 = 917
    D_C1_157 = 918
    D_C1_158 = 919
    D_C1_159 = 920
    D_C1_160 = 921
    D_C1_161 = 922
    D_C1_162 = 923
    D_C1_163 = 924
    D_C1_164 = 925
    D_C1_165 = 926
    D_C1_166 = 927
    D_C1_167 = 928
    D_C1_168 = 929
    D_C1_169 = 930
    D_C1_170 = 931
    D_C1_171 = 932
    D_C1_172 = 933
    D_C1_173 = 934
    D_C1_174 = 935
    D_C1_175 = 936
    D_C1_176 = 937
    D_C1_177 = 938
    D_C1_178 = 939
    D_C1_179 = 940
    D_C1_180 = 941
    D_C1_181 = 942
    D_C1_182 = 943
    D_C1_183 = 944
    D_C1_184 = 945
    D_C1_185 = 946
    D_C1_186 = 947
    D_C1_187 = 948
    D_C1_188 = 949
    D_C1_189 = 950
    D_C1_190 = 951
    D_C1_191 = 952
    D_C1_192 = 953
    D_C1_193 = 954
    D_C1_194 = 955
    D_C1_195 = 956
    D_C1_196 = 957
    D_C1_197 = 958
    D_C1_198 = 959
    D_C1_199 = 960
    D_C1_200 = 961
    D_C1_201 = 962
    D_C1_202 = 963
    D_C1_203 = 964
    D_C1_204 = 965
    D_C1_205 = 966
    D_C1_206 = 967
    D_C1_207 = 968
    D_C1_208 = 969
    D_C1_209 = 970
    D_C1_210 = 971
    D_C1_211 = 972
    D_C1_212 = 973
    D_C1_213 = 974
    D_C1_214 = 975
    D_C1_215 = 976
    D_C1_216 = 977
    D_C1_217 = 978
    D_C1_218 = 979
    D_C1_219 = 980
    D_C1_220 = 981
    D_C1_221 = 982
    D_C1_222 = 983
    D_C1_223 = 984
    D_C1_224 = 985
    D_C1_225 = 986
    D_C1_226 = 987
    D_C1_227 = 988
    D_C1_228 = 989
    D_C1_229 = 990
    D_C1_230 = 991
    D_C1_231 = 992
    D_C1_232 = 993
    D_C1_233 = 994
    D_C1_234 = 995
    D_C1_235 = 996
    D_C1_236 = 997
    D_C1_237 = 998
    D_C1_238 = 999
    D_C1_239 = 1000
    D_C1_240 = 1001
    D_C1_241 = 1002
    D_C1_242 = 1003
    D_C1_243 = 1004
    D_C1_244 = 1005
    D_C1_245 = 1006
    D_C1_246 = 1007
    D_C1_247 = 1008
    D_C1_248 = 1009
    D_C1_249 = 1010
    D_C1_250 = 1011
    D_C1_251 = 1012
    D_C1_252 = 1013
    D_C1_253 = 1014
    D_C1_254 = 1015
    D_C1_255 = 1016
    D_C1_256 = 1017
    D_C1_257 = 1018
    D_C1_258 = 1019
    D_C1_259 = 1020
    D_C1_260 = 1021
    D_C1_261 = 1022
    D_C1_262 = 1023
    D_C1_263 = 1024
    D_C1_264 = 1025
    D_C1_265 = 1026
    D_C1_266 = 1027
    D_C1_267 = 1028
    D_C1_268 = 1029
    D_C1_269 = 1030
    D_C1_270 = 1031
    D_C1_271 = 1032
    D_C1_272 = 1033
    D_C1_273 = 1034
    D_C1_274 = 1035
    D_C1_275 = 1036
    D_C1_276 = 1037
    D_C1_277 = 1038
    D_C1_278 = 1039
    D_C1_279 = 1040
    D_C1_280 = 1041
    D_C1_281 = 1042
    D_C1_282 = 1043
    D_C1_283 = 1044
    D_C1_284 = 1045
    D_C1_285 = 1046
    D_C1_286 = 1047
    D_C1_287 = 1048
    D_C1_288 = 1049
    D_C1_289 = 1050
    D_C1_290 = 1051
    D_C1_291 = 1052
    D_C1_292 = 1053
    D_C1_293 = 1054
    D_C1_294 = 1055
    D_C1_295 = 1056
    D_C1_296 = 1057
    D_C1_297 = 1058
    D_C1_298 = 1059
    D_C1_299 = 1060
    D_C1_300 = 1061
    D_C2_151 = 1062
    D_C2_152 = 1063
    D_C2_153 = 1064
    D_C2_154 = 1065
    D_C2_155 = 1066
    D_C2_156 = 1067
    D_C2_157 = 1068
    D_C2_158 = 1069
    D_C2_159 = 1070
    D_C2_160 = 1071
    D_C2_161 = 1072
    D_C2_162 = 1073
    D_C2_163 = 1074
    D_C2_164 = 1075
    D_C2_165 = 1076
    D_C2_166 = 1077
    D_C2_167 = 1078
    D_C2_168 = 1079
    D_C2_169 = 1080
    D_C2_170 = 1081
    D_C2_171 = 1082
    D_C2_172 = 1083
    D_C2_173 = 1084
    D_C2_174 = 1085
    D_C2_175 = 1086
    D_C2_176 = 1087
    D_C2_177 = 1088
    D_C2_178 = 1089
    D_C2_179 = 1090
    D_C2_180 = 1091
    D_C2_181 = 1092
    D_C2_182 = 1093
    D_C2_183 = 1094
    D_C2_184 = 1095
    D_C2_185 = 1096
    D_C2_186 = 1097
    D_C2_187 = 1098
    D_C2_188 = 1099
    D_C2_189 = 1100
    D_C2_190 = 1101
    D_C2_191 = 1102
    D_C2_192 = 1103
    D_C2_193 = 1104
    D_C2_194 = 1105
    D_C2_195 = 1106
    D_C2_196 = 1107
    D_C2_197 = 1108
    D_C2_198 = 1109
    D_C2_199 = 1110
    D_C2_200 = 1111
    D_C2_201 = 1112
    D_C2_202 = 1113
    D_C2_203 = 1114
    D_C2_204 = 1115
    D_C2_205 = 1116
    D_C2_206 = 1117
    D_C2_207 = 1118
    D_C2_208 = 1119
    D_C2_209 = 1120
    D_C2_210 = 1121
    D_C2_211 = 1122
    D_C2_212 = 1123
    D_C2_213 = 1124
    D_C2_214 = 1125
    D_C2_215 = 1126
    D_C2_216 = 1127
    D_C2_217 = 1128
    D_C2_218 = 1129
    D_C2_219 = 1130
    D_C2_220 = 1131
    D_C2_221 = 1132
    D_C2_222 = 1133
    D_C2_223 = 1134
    D_C2_224 = 1135
    D_C2_225 = 1136
    D_C2_226 = 1137
    D_C2_227 = 1138
    D_C2_228 = 1139
    D_C2_229 = 1140
    D_C2_230 = 1141
    D_C2_231 = 1142
    D_C2_232 = 1143
    D_C2_233 = 1144
    D_C2_234 = 1145
    D_C2_235 = 1146
    D_C2_236 = 1147
    D_C2_237 = 1148
    D_C2_238 = 1149
    D_C2_239 = 1150
    D_C2_240 = 1151
    D_C2_241 = 1152
    D_C2_242 = 1153
    D_C2_243 = 1154
    D_C2_244 = 1155
    D_C2_245 = 1156
    D_C2_246 = 1157
    D_C2_247 = 1158
    D_C2_248 = 1159
    D_C2_249 = 1160
    D_C2_250 = 1161
    D_C2_251 = 1162
    D_C2_252 = 1163
    D_C2_253 = 1164
    D_C2_254 = 1165
    D_C2_255 = 1166
    D_C2_256 = 1167
    D_C2_257 = 1168
    D_C2_258 = 1169
    D_C2_259 = 1170
    D_C2_260 = 1171
    D_C2_261 = 1172
    D_C2_262 = 1173
    D_C2_263 = 1174
    D_C2_264 = 1175
    D_C2_265 = 1176
    D_C2_266 = 1177
    D_C2_267 = 1178
    D_C2_268 = 1179
    D_C2_269 = 1180
    D_C2_270 = 1181
    D_C2_271 = 1182
    D_C2_272 = 1183
    D_C2_273 = 1184
    D_C2_274 = 1185
    D_C2_275 = 1186
    D_C2_276 = 1187
    D_C2_277 = 1188
    D_C2_278 = 1189
    D_C2_279 = 1190
    D_C2_280 = 1191
    D_C2_281 = 1192
    D_C2_282 = 1193
    D_C2_283 = 1194
    D_C2_284 = 1195
    D_C2_285 = 1196
    D_C2_286 = 1197
    D_C2_287 = 1198
    D_C2_288 = 1199
    D_C2_289 = 1200
    D_C2_290 = 1201
    D_C2_291 = 1202
    D_C2_292 = 1203
    D_C2_293 = 1204
    D_C2_294 = 1205
    D_C2_295 = 1206
    D_C2_296 = 1207
    D_C2_297 = 1208
    D_C2_298 = 1209
    D_C2_299 = 1210
    D_C2_300 = 1211
    D_C3_151 = 1212
    D_C3_152 = 1213
    D_C3_153 = 1214
    D_C3_154 = 1215
    D_C3_155 = 1216
    D_C3_156 = 1217
    D_C3_157 = 1218
    D_C3_158 = 1219
    D_C3_159 = 1220
    D_C3_160 = 1221
    D_C3_161 = 1222
    D_C3_162 = 1223
    D_C3_163 = 1224
    D_C3_164 = 1225
    D_C3_165 = 1226
    D_C3_166 = 1227
    D_C3_167 = 1228
    D_C3_168 = 1229
    D_C3_169 = 1230
    D_C3_170 = 1231
    D_C3_171 = 1232
    D_C3_172 = 1233
    D_C3_173 = 1234
    D_C3_174 = 1235
    D_C3_175 = 1236
    D_C3_176 = 1237
    D_C3_177 = 1238
    D_C3_178 = 1239
    D_C3_179 = 1240
    D_C3_180 = 1241
    D_C3_181 = 1242
    D_C3_182 = 1243
    D_C3_183 = 1244
    D_C3_184 = 1245
    D_C3_185 = 1246
    D_C3_186 = 1247
    D_C3_187 = 1248
    D_C3_188 = 1249
    D_C3_189 = 1250
    D_C3_190 = 1251
    D_C3_191 = 1252
    D_C3_192 = 1253
    D_C3_193 = 1254
    D_C3_194 = 1255
    D_C3_195 = 1256
    D_C3_196 = 1257
    D_C3_197 = 1258
    D_C3_198 = 1259
    D_C3_199 = 1260
    D_C3_200 = 1261
    D_C3_201 = 1262
    D_C3_202 = 1263
    D_C3_203 = 1264
    D_C3_204 = 1265
    D_C3_205 = 1266
    D_C3_206 = 1267
    D_C3_207 = 1268
    D_C3_208 = 1269
    D_C3_209 = 1270
    D_C3_210 = 1271
    D_C3_211 = 1272
    D_C3_212 = 1273
    D_C3_213 = 1274
    D_C3_214 = 1275
    D_C3_215 = 1276
    D_C3_216 = 1277
    D_C3_217 = 1278
    D_C3_218 = 1279
    D_C3_219 = 1280
    D_C3_220 = 1281
    D_C3_221 = 1282
    D_C3_222 = 1283
    D_C3_223 = 1284
    D_C3_224 = 1285
    D_C3_225 = 1286
    D_C3_226 = 1287
    D_C3_227 = 1288
    D_C3_228 = 1289
    D_C3_229 = 1290
    D_C3_230 = 1291
    D_C3_231 = 1292
    D_C3_232 = 1293
    D_C3_233 = 1294
    D_C3_234 = 1295
    D_C3_235 = 1296
    D_C3_236 = 1297
    D_C3_237 = 1298
    D_C3_238 = 1299
    D_C3_239 = 1300
    D_C3_240 = 1301
    D_C3_241 = 1302
    D_C3_242 = 1303
    D_C3_243 = 1304
    D_C3_244 = 1305
    D_C3_245 = 1306
    D_C3_246 = 1307
    D_C3_247 = 1308
    D_C3_248 = 1309
    D_C3_249 = 1310
    D_C3_250 = 1311
    D_C3_251 = 1312
    D_C3_252 = 1313
    D_C3_253 = 1314
    D_C3_254 = 1315
    D_C3_255 = 1316
    D_C3_256 = 1317
    D_C3_257 = 1318
    D_C3_258 = 1319
    D_C3_259 = 1320
    D_C3_260 = 1321
    D_C3_261 = 1322
    D_C3_262 = 1323
    D_C3_263 = 1324
    D_C3_264 = 1325
    D_C3_265 = 1326
    D_C3_266 = 1327
    D_C3_267 = 1328
    D_C3_268 = 1329
    D_C3_269 = 1330
    D_C3_270 = 1331
    D_C3_271 = 1332
    D_C3_272 = 1333
    D_C3_273 = 1334
    D_C3_274 = 1335
    D_C3_275 = 1336
    D_C3_276 = 1337
    D_C3_277 = 1338
    D_C3_278 = 1339
    D_C3_279 = 1340
    D_C3_280 = 1341
    D_C3_281 = 1342
    D_C3_282 = 1343
    D_C3_283 = 1344
    D_C3_284 = 1345
    D_C3_285 = 1346
    D_C3_286 = 1347
    D_C3_287 = 1348
    D_C3_288 = 1349
    D_C3_289 = 1350
    D_C3_290 = 1351
    D_C3_291 = 1352
    D_C3_292 = 1353
    D_C3_293 = 1354
    D_C3_294 = 1355
    D_C3_295 = 1356
    D_C3_296 = 1357
    D_C3_297 = 1358
    D_C3_298 = 1359
    D_C3_299 = 1360
    D_C3_300 = 1361
    MB_Zone1 = 1362
    MB_Zone2 = 1363
    MB_Zone3 = 1364
    MB_Zone4 = 1365
    MB_Zone5 = 1366
    MB_Zone6 = 1367
    MB_Zone7 = 1368
    MB_Zone8 = 1369
    MB_Zone9 = 1370
    MB_Zone10 = 1371
    MB_Zone11 = 1372
    MB_Zone12 = 1373
    MB_Zone13 = 1374
    MB_Zone14 = 1375
    MB_Zone15 = 1376
    MB_Zone16 = 1377
    MB_Zone17 = 1378
    MB_Zone18 = 1379
    MB_Zone19 = 1380
    MB_Zone20 = 1381
    MB_Zone21 = 1382
    MB_Zone22 = 1383
    MB_Zone23 = 1384
    MB_Zone24 = 1385
    MB_Zone25 = 1386
    MB_Zone26 = 1387
    MB_Zone27 = 1388
    MB_Zone28 = 1389
    MB_Zone29 = 1390
    MB_Zone30 = 1391
    MB_Zone31 = 1392
    MB_Zone32 = 1393
    MB_Zone33 = 1394
    MB_Zone34 = 1395
    MB_Zone35 = 1396
    MB_Zone36 = 1397
    MB_Zone37 = 1398
    MB_Zone38 = 1399
    MB_Zone39 = 1400
    MB_Zone40 = 1401
    MB_Zone41 = 1402
    MB_Zone42 = 1403
    MB_Zone43 = 1404
    MB_Zone44 = 1405
    MB_Zone45 = 1406
    MB_Zone46 = 1407
    MB_Zone47 = 1408
    MB_Zone48 = 1409
    MB_Zone49 = 1410
    MB_Zone50 = 1411
    MB_Zone51 = 1412
    MB_Zone52 = 1413
    MB_Zone53 = 1414
    MB_Zone54 = 1415
    MB_Zone55 = 1416
    MB_Zone56 = 1417
    MB_Zone57 = 1418
    MB_Zone58 = 1419
    MB_Zone59 = 1420
    MB_Zone60 = 1421
    MB_Zone61 = 1422
    MB_Zone62 = 1423
    MB_Zone63 = 1424
    MB_Zone64 = 1425
    MB_Zone65 = 1426
    MB_Zone66 = 1427
    MB_Zone67 = 1428
    MB_Zone68 = 1429
    MB_Zone69 = 1430
    MB_Zone70 = 1431
    MB_Zone71 = 1432
    MB_Zone72 = 1433
    MB_Zone73 = 1434
    MB_Zone74 = 1435
    MB_Zone75 = 1436
    MB_Zone76 = 1437
    MB_Zone77 = 1438
    MB_Zone78 = 1439
    MB_Zone79 = 1440
    MB_Zone80 = 1441
    MB_Zone81 = 1442
    MB_Zone82 = 1443
    MB_Zone83 = 1444
    MB_Zone84 = 1445
    MB_Zone85 = 1446
    MB_Zone86 = 1447
    MB_Zone87 = 1448
    MB_Zone88 = 1449
    MB_Zone89 = 1450
    MB_Zone90 = 1451
    MB_Zone91 = 1452
    MB_Zone92 = 1453
    MB_Zone93 = 1454
    MB_Zone94 = 1455
    MB_Zone95 = 1456
    MB_Zone96 = 1457
    MB_Zone97 = 1458
    MB_Zone98 = 1459
    MB_Zone99 = 1460
    MB_Zone100 = 1461
    GPU_Zone1 = 1462
    GPU_Zone2 = 1463
    GPU_Zone3 = 1464
    GPU_Zone4 = 1465
    GPU_Zone5 = 1466
    GPU_Zone6 = 1467
    GPU_Zone7 = 1468
    GPU_Zone8 = 1469
    GPU_Zone9 = 1470
    GPU_Zone10 = 1471
    GPU_Zone11 = 1472
    GPU_Zone12 = 1473
    GPU_Zone13 = 1474
    GPU_Zone14 = 1475
    GPU_Zone15 = 1476
    GPU_Zone16 = 1477
    GPU_Zone17 = 1478
    GPU_Zone18 = 1479
    GPU_Zone19 = 1480
    GPU_Zone20 = 1481
    GPU_Zone21 = 1482
    GPU_Zone22 = 1483
    GPU_Zone23 = 1484
    GPU_Zone24 = 1485
    GPU_Zone25 = 1486
    GPU_Zone26 = 1487
    GPU_Zone27 = 1488
    GPU_Zone28 = 1489
    GPU_Zone29 = 1490
    GPU_Zone30 = 1491
    GPU_Zone31 = 1492
    GPU_Zone32 = 1493
    GPU_Zone33 = 1494
    GPU_Zone34 = 1495
    GPU_Zone35 = 1496
    GPU_Zone36 = 1497
    GPU_Zone37 = 1498
    GPU_Zone38 = 1499
    GPU_Zone39 = 1500
    GPU_Zone40 = 1501
    GPU_Zone41 = 1502
    GPU_Zone42 = 1503
    GPU_Zone43 = 1504
    GPU_Zone44 = 1505
    GPU_Zone45 = 1506
    GPU_Zone46 = 1507
    GPU_Zone47 = 1508
    GPU_Zone48 = 1509
    GPU_Zone49 = 1510
    GPU_Zone50 = 1511
    KLP_Zone20 = 1512
    KLP_Zone21 = 1513
    KLP_Zone22 = 1514
    KLP_Zone23 = 1515
    KLP_Zone24 = 1516
    KLP_Zone25 = 1517
    KLP_Zone26 = 1518
    KLP_Zone27 = 1519
    KLP_Zone28 = 1520
    KLP_Zone29 = 1521
    KLP_Zone30 = 1522
    KLP_Zone31 = 1523
    KLP_Zone32 = 1524
    KLP_Zone33 = 1525
    KLP_Zone34 = 1526
    KLP_Zone35 = 1527
    KLP_Zone36 = 1528
    KLP_Zone37 = 1529
    KLP_Zone38 = 1530
    KLP_Zone39 = 1531
    KLP_Zone40 = 1532
    KLP_Zone41 = 1533
    KLP_Zone42 = 1534
    KLP_Zone43 = 1535
    KLP_Zone44 = 1536
    KLP_Zone45 = 1537
    KLP_Zone46 = 1538
    KLP_Zone47 = 1539
    KLP_Zone48 = 1540
    KLP_Zone49 = 1541
    KLP_Zone50 = 1542
    K_Profile = 1543
    Oem101 = 1544
    Oem102 = 1545
    Oem103 = 1546
    Oem104 = 1547
    Oem105 = 1548
    Oem106 = 1549
    Oem107 = 1550
    Oem108 = 1551
    Oem109 = 1552
    Oem110 = 1553
    Oem111 = 1554
    Oem112 = 1555
    Oem113 = 1556
    Oem114 = 1557
    Oem115 = 1558
    Oem116 = 1559
    Oem117 = 1560
    Oem118 = 1561
    Oem119 = 1562
    Oem120 = 1563
    Oem121 = 1564
    Oem122 = 1565
    Oem123 = 1566
    Oem124 = 1567
    Oem125 = 1568
    Oem126 = 1569
    Oem127 = 1570
    Oem128 = 1571
    Oem129 = 1572
    Oem130 = 1573
    Oem131 = 1574
    Oem132 = 1575
    Oem133 = 1576
    Oem134 = 1577
    Oem135 = 1578
    Oem136 = 1579
    Oem137 = 1580
    Oem138 = 1581
    Oem139 = 1582
    Oem140 = 1583
    Oem141 = 1584
    Oem142 = 1585
    Oem143 = 1586
    Oem144 = 1587
    Oem145 = 1588
    Oem146 = 1589
    Oem147 = 1590
    Oem148 = 1591
    Oem149 = 1592
    Oem150 = 1593
    Oem151 = 1594
    Oem152 = 1595
    Oem153 = 1596
    Oem154 = 1597
    Oem155 = 1598
    Oem156 = 1599
    Oem157 = 1600
    Oem158 = 1601
    Oem159 = 1602
    Oem160 = 1603
    Oem161 = 1604
    Oem162 = 1605
    Oem163 = 1606
    Oem164 = 1607
    Oem165 = 1608
    Oem166 = 1609
    Oem167 = 1610
    Oem168 = 1611
    Oem169 = 1612
    Oem170 = 1613
    Oem171 = 1614
    Oem172 = 1615
    Oem173 = 1616
    Oem174 = 1617
    Oem175 = 1618
    Oem176 = 1619
    Oem177 = 1620
    Oem178 = 1621
    Oem179 = 1622
    Oem180 = 1623
    Oem181 = 1624
    Oem182 = 1625
    Oem183 = 1626
    Oem184 = 1627
    Oem185 = 1628
    Oem186 = 1629
    Oem187 = 1630
    Oem188 = 1631
    Oem189 = 1632
    Oem190 = 1633
    Oem191 = 1634
    Oem192 = 1635
    Oem193 = 1636
    Oem194 = 1637
    Oem195 = 1638
    Oem196 = 1639
    Oem197 = 1640
    Oem198 = 1641
    Oem199 = 1642
    Oem200 = 1643
    Oem201 = 1644
    Oem202 = 1645
    Oem203 = 1646
    Oem204 = 1647
    Oem205 = 1648
    Oem206 = 1649
    Oem207 = 1650
    Oem208 = 1651
    Oem209 = 1652
    Oem210 = 1653
    Oem211 = 1654
    Oem212 = 1655
    Oem213 = 1656
    Oem214 = 1657
    Oem215 = 1658
    Oem216 = 1659
    Oem217 = 1660
    Oem218 = 1661
    Oem219 = 1662
    Oem220 = 1663
    Oem221 = 1664
    Oem222 = 1665
    Oem223 = 1666
    Oem224 = 1667
    Oem225 = 1668
    Oem226 = 1669
    Oem227 = 1670
    Oem228 = 1671
    Oem229 = 1672
    Oem230 = 1673
    Oem231 = 1674
    Oem232 = 1675
    Oem233 = 1676
    Oem234 = 1677
    Oem235 = 1678
    Oem236 = 1679
    Oem237 = 1680
    Oem238 = 1681
    Oem239 = 1682
    Oem240 = 1683
    Oem241 = 1684
    Oem242 = 1685
    Oem243 = 1686
    Oem244 = 1687
    Oem245 = 1688
    Oem246 = 1689
    Oem247 = 1690
    Oem248 = 1691
    Oem249 = 1692
    Oem250 = 1693
    M_7 = 1694
    M_8 = 1695
    M_9 = 1696
    M_10 = 1697
    M_11 = 1698
    M_12 = 1699
    M_13 = 1700
    M_14 = 1701
    M_15 = 1702
    M_16 = 1703
    M_17 = 1704
    M_18 = 1705
    M_19 = 1706
    M_20 = 1707
    Last = M_20
